package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TSetting;
import com.ruoyi.system.service.ITSettingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 手环系统设置Controller
 * 
 * @author zhengjie
 * @date 2023-09-22
 */
@RestController
@RequestMapping("/system/setting")
public class TSettingController extends BaseController
{
    @Autowired
    private ITSettingService tSettingService;

    /**
     * 查询手环系统设置列表
     */
    @GetMapping("/list")
    public AjaxResult list(TSetting tSetting)
    {
        startPage();
        List<TSetting> list = tSettingService.selectTSettingList(tSetting);
        return success(list);
    }

    /**
     * 导出手环系统设置列表
     */
    @PreAuthorize("@ss.hasPermi('system:setting:export')")
    @Log(title = "手环系统设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSetting tSetting)
    {
        List<TSetting> list = tSettingService.selectTSettingList(tSetting);
        ExcelUtil<TSetting> util = new ExcelUtil<TSetting>(TSetting.class);
        util.exportExcel(response, list, "手环系统设置数据");
    }

    /**
     * 获取手环系统设置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:setting:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tSettingService.selectTSettingById(id));
    }

    /**
     * 新增手环系统设置
     */
    @PreAuthorize("@ss.hasPermi('system:setting:add')")
    @Log(title = "手环系统设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSetting tSetting)
    {
        return toAjax(tSettingService.insertTSetting(tSetting));
    }

    /**
     * 修改手环系统设置
     */
    @PreAuthorize("@ss.hasPermi('system:setting:edit')")
    @Log(title = "手环系统设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSetting tSetting)
    {
        return toAjax(tSettingService.updateTSetting(tSetting));
    }

    /**
     * 删除手环系统设置
     */
    @PreAuthorize("@ss.hasPermi('system:setting:remove')")
    @Log(title = "手环系统设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tSettingService.deleteTSettingByIds(ids));
    }
}
